-- Function: get_availability(bigint, bigint, timestamp without time zone, timestamp without time zone)

-- DROP FUNCTION get_availability(bigint, bigint, timestamp without time zone, timestamp without time zone);

CREATE OR REPLACE FUNCTION get_availability(
    nodeid bigint,
    serviceid bigint,
    stardate timestamp without time zone,
    enddate timestamp without time zone)
  RETURNS real AS
$BODY$
DECLARE 
	nbrsec bigint;
	v_ava real = 100;
	percent real;
	r RECORD;
BEGIN		
	SELECT date_part('epoch', enddate - stardate) INTO nbrsec;
	--CALCUL du nombre de seconde d'indisponnibilité
	FOR r IN SELECT error_type,SUM (sec_in_error) as time_notavailable 
		FROM (
			--Si l'erreur c'est produite entre l'interval de temps
			SELECT error_type, date_part('epoch',SUM(happen_time_acquitte - happen_timestamp)) as sec_in_error
			FROM ( 
				SELECT error_type, happen_timestamp, happen_time_acquitte
				FROM esia_error_happen
				LEFT JOIN esia_errors ON error_id = happen_error_id
				WHERE happen_service_id = serviceid AND happen_device_id = nodeid AND error_type <> 'unknown' AND error_type <> 'maintenance'
					AND happen_timestamp > stardate
					AND happen_timestamp < enddate
				) AS T2
			WHERE T2.happen_time_acquitte < enddate
			GROUP BY T2.error_type

			UNION
			--Si l'erreur c'est produite durant l'interval de temps et que le acuitte es§t toujours actif ou après le enddate
			SELECT error_type, date_part('epoch',SUM(happen_time_acquitte - happen_timestamp)) as sec_in_error
			FROM  ( 
				SELECT error_type, happen_timestamp, happen_time_acquitte
				FROM esia_error_happen
				LEFT JOIN esia_errors ON error_id = happen_error_id
				WHERE happen_service_id = serviceid AND happen_device_id = nodeid AND error_type <> 'unknown' AND error_type <> 'maintenance'
					AND happen_timestamp > stardate
					AND happen_timestamp < enddate
			) AS T2
			WHERE happen_time_acquitte > enddate 
				OR happen_time_acquitte IS NULL 
			GROUP BY error_type
			
			UNION
			--si l'erreur c'est produite avant la start date et est toujours active ou que le time acquite est après la date de fin
			SELECT error_type, date_part('epoch',SUM(enddate - stardate)) as sec_in_error
			FROM esia_error_happen
			LEFT JOIN esia_errors ON error_id = happen_error_id
			WHERE happen_service_id = serviceid AND error_type <> 'unknown' AND error_type <> 'maintenance'
				AND happen_timestamp < stardate
				AND ( happen_acquitte=0 OR happen_time_acquitte > enddate)
			GROUP BY error_type
				--service non présent
			UNION
				SELECT 'nopresent' as error_type,date_part('epoch',SUM(enddate -stardate )) as sec_in_error
				FROM esia_services
				WHERE service_id = serviceid
					AND service_time_added >  stardate
			) A GROUP BY error_type
	LOOP
		--RAISE NOTICE 'i want to print % and % %', r.time_notavailable ,r.error_type,nbrsec ;
		IF r.time_notavailable <> 0
		THEN
			percent = (r.time_notavailable / nbrsec)*100;
		ELSE
			percent=0;
		END IF;
		--RAISE NOTICE 'percent: %',percent;
		v_ava = v_ava - percent;
	END LOOP;
	return v_ava;

END;
$BODY$
  LANGUAGE plpgsql VOLATILE
  COST 100;
ALTER FUNCTION get_availability(bigint, bigint, timestamp without time zone, timestamp without time zone)
  OWNER TO esia;
  
-- GRAPH ONGLET RAPPORT SUR LE NOEUD------ END  
