--
-- PostgreSQL database dump
--

-- Dumped from database version 9.4.1
-- Dumped by pg_dump version 9.4.4
-- Started on 2015-07-29 14:08:39 CEST

SET statement_timeout = 0;
SET lock_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = on;
SET check_function_bodies = false;
SET client_min_messages = warning;

--
-- TOC entry 242 (class 3079 OID 11861)
-- Name: plpgsql; Type: EXTENSION; Schema: -; Owner: -
--

CREATE EXTENSION IF NOT EXISTS plpgsql WITH SCHEMA pg_catalog;


--
-- TOC entry 2511 (class 0 OID 0)
-- Dependencies: 242
-- Name: EXTENSION plpgsql; Type: COMMENT; Schema: -; Owner: -
--

--COMMENT ON EXTENSION plpgsql IS 'PL/pgSQL procedural language';


SET search_path = public, pg_catalog;

--
-- TOC entry 255 (class 1255 OID 16386)
-- Name: count_service(); Type: FUNCTION; Schema: public; Owner: -
--

CREATE FUNCTION count_service() RETURNS integer
    LANGUAGE plpgsql
    AS $$
	DECLARE 
		v_service integer;
        BEGIN
		SELECT count(*) INTO v_service
		FROM esia_services
		JOIN esia_device ON service_device_id = device_id
		WHERE service_delete=FALSE AND service_name <> 'GESA_HEALTH' AND device_ip_addr<>2130706433;
		RETURN v_service;
		
   END;
$$;


--
-- TOC entry 256 (class 1255 OID 16387)
-- Name: count_service(integer, integer); Type: FUNCTION; Schema: public; Owner: -
--

CREATE FUNCTION count_service(v_year integer, v_month integer) RETURNS integer
    LANGUAGE plpgsql
    AS $$
	DECLARE 
		v_sms integer;
        BEGIN
		SELECT count(*) INTO v_sms 
		FROM sms_send
		WHERE sms_date > date (v_year||'-'||v_month||'-01') 
			AND  sms_date < date (v_year||'-'||v_month||'-01')  +interval '1 month';
		RETURN v_sms;
		
   END;
$$;


--
-- TOC entry 257 (class 1255 OID 16388)
-- Name: trigger_delete_device(); Type: FUNCTION; Schema: public; Owner: -
--

CREATE FUNCTION trigger_delete_device() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
    ForKEY RECORD;
BEGIN
	FOR ForKEY IN SELECT tc.table_name, kcu.column_name, ccu.table_name AS foreign_table_name,ccu.column_name AS foreign_column_name 
		FROM information_schema.table_constraints  tc 
		JOIN information_schema.key_column_usage kcu ON tc.constraint_name = kcu.constraint_name 
		JOIN information_schema.constraint_column_usage ccu ON ccu.constraint_name = tc.constraint_name WHERE constraint_type = 'FOREIGN KEY' AND ccu.table_name='esia_device' LOOP

	EXECUTE 'DELETE FROM '|| ForKEY.table_name || ' WHERE '||ForKEY.column_name||' = '||OLD.device_id;
	END LOOP;
	RETURN OLD;
END;
$$;


--
-- TOC entry 258 (class 1255 OID 16389)
-- Name: trigger_delete_service(); Type: FUNCTION; Schema: public; Owner: -
--

CREATE FUNCTION trigger_delete_service() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
	DELETE FROM esia_error_happen WHERE happen_service_id = OLD.service_id;
	DELETE FROM esia_service_response_program WHERE response_service_id = OLD.service_id;

	RETURN OLD;
END;
$$;

CREATE OR REPLACE FUNCTION getdeviceingroup(
    IN userid integer,
    IN groupid integer)
  RETURNS TABLE(device_id integer) AS
$BODY$
    DECLARE
        v_service integer;
        BEGIN
	IF (groupid IS NOT NULL)
	THEN
		RETURN QUERY SELECT T1.device_id
				FROM esia_device AS T1
				JOIN esia_device_group_in ON T1.device_id = group_in_device_id
				JOIN esia_device_group ON device_group_id= group_in_device_group_id
				WHERE T1.device_id IN ( SELECT * FROM getUserAccessNode(userid)) AND device_delete=FALSE AND device_group_id = groupid ;
	ELSE
		RETURN QUERY SELECT T1.device_id
		FROM esia_device AS T1
		WHERE T1.device_id IN ( SELECT * FROM getUserAccessNode(userid)) AND device_delete=FALSE
			AND NOT EXISTS(SELECT group_in_device_id FROM esia_device_group_in WHERE group_in_device_id = T1.device_id);
	END IF;

   END;
$BODY$
  LANGUAGE plpgsql VOLATILE
  COST 100
  ROWS 1000;
CREATE OR REPLACE FUNCTION get_availability(
    nodeid bigint,
    serviceid bigint,
    enddate date,
    inter interval)
  RETURNS real AS
$BODY$
DECLARE 
	stardate timestamp without time zone;
BEGIN	
	--on calcul le nombre de seconde dans l'interval de temps
	SELECT (enddate - inter) INTO stardate;
	RETURN get_availability(nodeid,serviceid,stardate,enddate);
END;
$BODY$
  LANGUAGE plpgsql VOLATILE
  COST 100;
ALTER FUNCTION get_availability(bigint, bigint, date, interval)
  OWNER TO esia;

-- Function: get_availability(bigint, bigint, timestamp without time zone, timestamp without time zone)

-- DROP FUNCTION get_availability(bigint, bigint, timestamp without time zone, timestamp without time zone);

CREATE OR REPLACE FUNCTION get_availability(
    nodeid bigint,
    serviceid bigint,
    stardate timestamp without time zone,
    enddate timestamp without time zone)
  RETURNS real AS
$BODY$
DECLARE 
	nbrsec bigint;
	v_ava real = 100;
	percent real;
	r RECORD;
BEGIN		
	SELECT date_part('epoch', enddate - stardate) INTO nbrsec;
	--CALCUL du nombre de seconde d'indisponnibilité
	FOR r IN SELECT error_type,SUM (sec_in_error) as time_notavailable 
		FROM (
			--Si l'erreur c'est produite entre l'interval de temps
			SELECT error_type, date_part('epoch',SUM(happen_time_acquitte - happen_timestamp)) as sec_in_error
			FROM ( 
				SELECT error_type, happen_timestamp, happen_time_acquitte
				FROM esia_error_happen
				LEFT JOIN esia_errors ON error_id = happen_error_id
				WHERE happen_service_id = serviceid AND happen_device_id = nodeid AND error_type <> 'unknown'
					AND happen_timestamp > stardate
					AND happen_timestamp < enddate
				) AS T2
			WHERE T2.happen_time_acquitte < enddate
			GROUP BY T2.error_type

			UNION
			--Si l'erreur c'est produite durant l'interval de temps et que le acuitte es§t toujours actif ou après le enddate
			SELECT error_type, date_part('epoch',SUM(happen_time_acquitte - happen_timestamp)) as sec_in_error
			FROM  ( 
				SELECT error_type, happen_timestamp, happen_time_acquitte
				FROM esia_error_happen
				LEFT JOIN esia_errors ON error_id = happen_error_id
				WHERE happen_service_id = serviceid AND happen_device_id = nodeid AND error_type <> 'unknown'
					AND happen_timestamp > stardate
					AND happen_timestamp < enddate
			) AS T2
			WHERE happen_time_acquitte > enddate 
				OR happen_time_acquitte IS NULL 
			GROUP BY error_type
			
			UNION
			--si l'erreur c'est produite avant la start date et est toujours active ou que le time acquite est après la date de fin
			SELECT error_type, date_part('epoch',SUM(enddate - stardate)) as sec_in_error
			FROM esia_error_happen
			LEFT JOIN esia_errors ON error_id = happen_error_id
			WHERE happen_service_id = serviceid AND error_type <> 'unknown'
				AND happen_timestamp < stardate
				AND ( happen_acquitte=0 OR happen_time_acquitte > enddate)
			GROUP BY error_type
				--service non présent
			UNION
				SELECT 'nopresent' as error_type,date_part('epoch',SUM(enddate -stardate )) as sec_in_error
				FROM esia_services
				WHERE service_id = serviceid
					AND service_time_added >  stardate
			) A GROUP BY error_type
	LOOP
		--RAISE NOTICE 'i want to print % and % %', r.time_notavailable ,r.error_type,nbrsec ;
		IF r.time_notavailable <> 0
		THEN
			percent = (r.time_notavailable / nbrsec)*100;
		ELSE
			percent=0;
		END IF;
		--RAISE NOTICE 'percent: %',percent;
		v_ava = v_ava - percent;
	END LOOP;
	return v_ava;
	


END;
$BODY$
  LANGUAGE plpgsql VOLATILE
  COST 100;
ALTER FUNCTION get_availability(bigint, bigint, timestamp without time zone, timestamp without time zone)
  OWNER TO esia;

-- Function: get_timeerror(bigint, bigint, timestamp without time zone, timestamp without time zone)

-- DROP FUNCTION get_timeerror(bigint, bigint, timestamp without time zone, timestamp without time zone);

CREATE OR REPLACE FUNCTION get_timeerror(
    IN nodeid bigint,
    IN serviceid bigint,
    IN stardate timestamp without time zone,
    IN enddate timestamp without time zone)
  RETURNS TABLE(type character varying, nbrsec double precision) AS
$BODY$
BEGIN		
	SELECT date_part('epoch', enddate - stardate) INTO nbrsec;
	--CALCUL du nombre de seconde d'indisponnibilité
	RETURN QUERY SELECT error_type,SUM (sec_in_error) as time_notavailable 
		FROM (
			--Si l'erreur c'est produite entre l'interval de temps
			SELECT error_type, date_part('epoch',SUM(happen_time_acquitte - happen_timestamp)) as sec_in_error
			FROM ( 
				SELECT error_type, happen_timestamp, happen_time_acquitte
				FROM esia_error_happen
				LEFT JOIN esia_errors ON error_id = happen_error_id
				WHERE happen_service_id = serviceid AND happen_device_id = nodeid
					AND happen_timestamp > stardate
					AND happen_timestamp < enddate
				) AS T2
			WHERE T2.happen_time_acquitte < enddate
			GROUP BY T2.error_type

			UNION
			--Si l'erreur c'est produite durant l'interval de temps et que le acuitte es§t toujours actif ou après le enddate
			SELECT error_type, date_part('epoch',SUM(enddate - happen_timestamp)) as sec_in_error
			FROM  ( 
				SELECT error_type, happen_timestamp, happen_time_acquitte
				FROM esia_error_happen
				LEFT JOIN esia_errors ON error_id = happen_error_id
				WHERE happen_service_id = serviceid AND happen_device_id = nodeid
					AND happen_timestamp > stardate
					AND happen_timestamp < enddate
			) AS T2
			WHERE happen_time_acquitte > enddate 
				OR happen_time_acquitte IS NULL 
			GROUP BY error_type
			
			UNION
			--si l'erreur c'est produite avant la start date et est toujours active ou que le time acquite est après la date de fin
			SELECT error_type, date_part('epoch',SUM(enddate - stardate)) as sec_in_error
			FROM esia_error_happen
			LEFT JOIN esia_errors ON error_id = happen_error_id
			WHERE happen_service_id = serviceid
				AND happen_timestamp < stardate
				AND ( happen_acquitte=0 OR happen_time_acquitte > enddate)
			GROUP BY error_type
				--service non présent
			UNION
				SELECT 'nopresent' as error_type,date_part('epoch',SUM(enddate -stardate )) as sec_in_error
				FROM esia_services
				WHERE service_id = serviceid
					AND service_time_added >  stardate
			) A GROUP BY error_type
		UNION 
		SELECT 'total', date_part('epoch', enddate - stardate);
	


END;
$BODY$
  LANGUAGE plpgsql VOLATILE
  COST 100
  ROWS 1000;
ALTER FUNCTION get_timeerror(bigint, bigint, timestamp without time zone, timestamp without time zone)
  OWNER TO esia;

SET default_with_oids = false;

--
-- TOC entry 172 (class 1259 OID 16390)
-- Name: esia_building; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE esia_building (
    building_id integer NOT NULL,
    building_name character varying NOT NULL,
    building_abreviation character varying(10),
    building_zone_id integer,
    building_latitude real,
    building_longitude real,
    building_description character varying(500)
);


--
-- TOC entry 173 (class 1259 OID 16396)
-- Name: esia_building_building_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE esia_building_building_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- TOC entry 2512 (class 0 OID 0)
-- Dependencies: 173
-- Name: esia_building_building_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE esia_building_building_id_seq OWNED BY esia_building.building_id;


--
-- TOC entry 174 (class 1259 OID 16398)
-- Name: esia_configuration; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE esia_configuration (
    config_key character varying(30) NOT NULL,
    config_value text,
    config_description text,
    config_type character varying(20) NOT NULL,
    config_visibility boolean DEFAULT true NOT NULL
);


--
-- TOC entry 175 (class 1259 OID 16405)
-- Name: esia_container; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE esia_container (
    container_id integer NOT NULL,
    container_name character varying(50),
    container_description character varying(200),
    container_photo character varying(150),
    container_type integer
);


--
-- TOC entry 176 (class 1259 OID 16408)
-- Name: esia_container_container_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE esia_container_container_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- TOC entry 2513 (class 0 OID 0)
-- Dependencies: 176
-- Name: esia_container_container_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE esia_container_container_id_seq OWNED BY esia_container.container_id;


--
-- TOC entry 177 (class 1259 OID 16410)
-- Name: esia_container_type; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE esia_container_type (
    container_type_id integer NOT NULL,
    container_type_name character varying(20)
);


--
-- TOC entry 178 (class 1259 OID 16413)
-- Name: esia_container_type_container_type_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE esia_container_type_container_type_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- TOC entry 2514 (class 0 OID 0)
-- Dependencies: 178
-- Name: esia_container_type_container_type_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE esia_container_type_container_type_id_seq OWNED BY esia_container_type.container_type_id;


--
-- TOC entry 179 (class 1259 OID 16415)
-- Name: esia_device; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE esia_device (
    device_id integer NOT NULL,
    device_name character varying(150) NOT NULL,
    device_type character varying(16),
    device_group_name character varying,
    device_description text,
    device_ip_addr bigint DEFAULT 0,
    device_username character varying(20),
    device_passwd bytea,
    device_snmp_community character varying(20),
    device_snmp_version integer,
    device_protocol_connection character varying(10),
    device_snmp3_user character varying,
    device_snmp3_sec_lvl character varying(20),
    device_snmp3_auth_protocole character varying(10),
    device_snmp3_auth_key character varying,
    device_ip_version smallint DEFAULT 4 NOT NULL,
    device_snmp3_priv_protocol character varying(10),
    device_snmp3_priv_passphrase character varying(50),
    device_snmp_timer integer DEFAULT 1000000,
    device_delete boolean DEFAULT false
);


--
-- TOC entry 180 (class 1259 OID 16425)
-- Name: esia_device_device_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE esia_device_device_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- TOC entry 2515 (class 0 OID 0)
-- Dependencies: 180
-- Name: esia_device_device_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE esia_device_device_id_seq OWNED BY esia_device.device_id;


--
-- TOC entry 182 (class 1259 OID 16433)
-- Name: esia_device_stored_container; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE esia_device_stored_container (
    stored_device_id bigint NOT NULL,
    stored_container_id bigint NOT NULL
);


--
-- TOC entry 183 (class 1259 OID 16436)
-- Name: esia_device_type; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE esia_device_type (
    type_id integer NOT NULL,
    type_name character varying(30) NOT NULL,
    type_web_id integer,
    type_admin_page character varying(100),
    type_img_ok_path character varying(100),
    type_img_warning_path character varying(100),
    type_img_critical_path character varying(100),
    type_img_unknown_path character varying(100),
    type_list_page character varying
);


--
-- TOC entry 184 (class 1259 OID 16442)
-- Name: esia_device_type_type_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE esia_device_type_type_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- TOC entry 2516 (class 0 OID 0)
-- Dependencies: 184
-- Name: esia_device_type_type_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE esia_device_type_type_id_seq OWNED BY esia_device_type.type_id;


--
-- TOC entry 185 (class 1259 OID 16444)
-- Name: esia_error_happen; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE esia_error_happen (
    happen_error_id integer NOT NULL,
    happen_device_id integer NOT NULL,
    happen_interface_id integer,
    happen_message character varying,
    happen_acquitte smallint DEFAULT 0 NOT NULL,
    happen_value integer DEFAULT 0,
    happen_service_id bigint,
    happen_time_acquitte timestamp without time zone,
    happen_timestamp timestamp without time zone DEFAULT now(),
    happen_id bigint NOT NULL,
	happen_user_id integer
);

CREATE TABLE report_canevas (
	canevas_id serial NOT NULL,
	canevas_name varchar NOT NULL,
	canevas_description varchar,
	canevas_interval interval,
	canevas_date_nextgeneration timestamp,
	canevas_parameter json,
	CONSTRAINT report_canevas_PrimaryKey PRIMARY KEY (canevas_id)
	);

CREATE TABLE report_block (
	block_id serial NOT NULL,
	block_name varchar,
	block_controller varchar,
	block_default_parameter json,
	CONSTRAINT report_block_PrimaryKey PRIMARY KEY (block_id)
	);

CREATE TABLE report_include_block (
	include_id serial NOT NULL,
	include_block_id integer,
	include_canevas_id integer,
	include_position integer,
	include_parameter json,
	CONSTRAINT report_include_block_PrimaryKey PRIMARY KEY (include_id),
	CONSTRAINT report_include_block_ForKey_include_block_id FOREIGN KEY (include_block_id)
	REFERENCES report_block(block_id) MATCH SIMPLE ON UPDATE NO ACTION ON DELETE NO ACTION,
	CONSTRAINT report_include_block_ForKey_include_canevas_id FOREIGN KEY (include_canevas_id)
	REFERENCES report_canevas(canevas_id) MATCH SIMPLE ON UPDATE NO ACTION ON DELETE NO ACTION
	);

CREATE TABLE report (
	id serial NOT NULL,
	name varchar,
	date_generate timestamp DEFAULT NOW(),
	path_html varchar,
	path_pdf varchar,
	canevas_id integer, 
	report_date_start timestamp,
	report_date_end timestamp,
	CONSTRAINT report_PrimaryKey PRIMARY KEY (id),
	CONSTRAINT report_ForKey_canevas_id FOREIGN KEY (canevas_id)
	REFERENCES report_canevas(canevas_id) MATCH SIMPLE ON UPDATE NO ACTION ON DELETE NO ACTION
	);

--
-- TOC entry 186 (class 1259 OID 16453)
-- Name: esia_error_happen_happen_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE esia_error_happen_happen_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- TOC entry 2517 (class 0 OID 0)
-- Dependencies: 186
-- Name: esia_error_happen_happen_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE esia_error_happen_happen_id_seq OWNED BY esia_error_happen.happen_id;


--
-- TOC entry 187 (class 1259 OID 16455)
-- Name: esia_errors; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE esia_errors (
    error_id integer NOT NULL,
    error_name character varying NOT NULL,
    error_type character varying DEFAULT 'critical'::character varying NOT NULL
);


--
-- TOC entry 188 (class 1259 OID 16462)
-- Name: esia_errors_error_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE esia_errors_error_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- TOC entry 2518 (class 0 OID 0)
-- Dependencies: 188
-- Name: esia_errors_error_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE esia_errors_error_id_seq OWNED BY esia_errors.error_id;


--
-- TOC entry 189 (class 1259 OID 16464)
-- Name: esia_floor; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE esia_floor (
    floor_id integer NOT NULL,
    floor_name character varying(50),
    floor_map character varying,
    floor_building_id integer
);


--
-- TOC entry 190 (class 1259 OID 16470)
-- Name: esia_floor_floor_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE esia_floor_floor_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- TOC entry 2519 (class 0 OID 0)
-- Dependencies: 190
-- Name: esia_floor_floor_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE esia_floor_floor_id_seq OWNED BY esia_floor.floor_id;


--
-- TOC entry 191 (class 1259 OID 16472)
-- Name: esia_group_device_access; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE esia_group_device_access (
    access_group_id integer NOT NULL,
    access_device_id integer NOT NULL
);


--
-- TOC entry 192 (class 1259 OID 16475)
-- Name: esia_groups; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE esia_groups (
    group_id integer NOT NULL,
    group_name character varying NOT NULL,
    group_description character varying(200)
);


--
-- TOC entry 193 (class 1259 OID 16481)
-- Name: esia_groups_group_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE esia_groups_group_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- TOC entry 2520 (class 0 OID 0)
-- Dependencies: 193
-- Name: esia_groups_group_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE esia_groups_group_id_seq OWNED BY esia_groups.group_id;


--
-- TOC entry 194 (class 1259 OID 16483)
-- Name: esia_interface; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE esia_interface (
    interface_id integer NOT NULL,
    interface_name character varying(100) NOT NULL,
    interface_type character varying(30),
    interface_desc character varying(60),
    interface_plug character varying(20),
    interface_toip integer DEFAULT (-1),
    interface_lastchange_username character varying(30),
    interface_down_time bigint DEFAULT 0,
    interface_critical smallint DEFAULT 0,
    interface_ifindex integer DEFAULT (-1),
    interface_device_id integer,
    interface_lastchange_time timestamp without time zone,
	interface_mac_addr macaddr
);


--
-- TOC entry 195 (class 1259 OID 16490)
-- Name: esia_interface_interface_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE esia_interface_interface_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- TOC entry 2521 (class 0 OID 0)
-- Dependencies: 195
-- Name: esia_interface_interface_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE esia_interface_interface_id_seq OWNED BY esia_interface.interface_id;


--
-- TOC entry 196 (class 1259 OID 16492)
-- Name: esia_localization; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE esia_localization (
    localization_id integer NOT NULL,
    localization_floor_id integer,
    localization_device_id integer,
    localization_x integer,
    localization_y integer,
    localization_rack_id integer,
    localization_width integer,
    localization_height integer,
    localization_container_id integer,
    localization_image_id integer
);


--
-- TOC entry 197 (class 1259 OID 16495)
-- Name: esia_localization_images; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE esia_localization_images (
    image_id integer NOT NULL,
    image_name character varying(50),
    image_description character varying(200),
    image_path_ok character varying(200),
    image_path_warning character varying(200),
    image_path_critical character varying(200),
    image_path_unknown character varying(200)
);


--
-- TOC entry 198 (class 1259 OID 16498)
-- Name: esia_localization_localization_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE esia_localization_localization_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- TOC entry 2522 (class 0 OID 0)
-- Dependencies: 198
-- Name: esia_localization_localization_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE esia_localization_localization_id_seq OWNED BY esia_localization.localization_id;


--
-- TOC entry 199 (class 1259 OID 16500)
-- Name: esia_mac; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE esia_mac (
    mac character varying NOT NULL
);


--
-- TOC entry 200 (class 1259 OID 16506)
-- Name: esia_mac_address; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE esia_mac_address (
    mac_address character varying(50) NOT NULL,
    mac_interface_id integer NOT NULL,
    mac_vlan_id integer NOT NULL,
    mac_ip_address character varying(54),
    mac_time_connection integer,
    mac_time_out_connection bigint DEFAULT 0,
    mac_dot1dport integer
);


--
-- TOC entry 201 (class 1259 OID 16510)
-- Name: esia_mac_address_vendor; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE esia_mac_address_vendor (
    vendor_mac_address character(6) NOT NULL,
    vendor_company character varying(100)
);


--
-- TOC entry 202 (class 1259 OID 16513)
-- Name: esia_manufacturer; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE esia_manufacturer (
    manufacturer_oid bigint NOT NULL,
    manufacturer_name character varying,
    manufacturer_logo character varying(100)
);


--
-- TOC entry 203 (class 1259 OID 16519)
-- Name: esia_php_class; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE esia_php_class (
    class_id bigint NOT NULL,
    class_name character varying,
    class_type character varying,
    class_path character varying,
    class_manufacturer_oid bigint
);


--
-- TOC entry 204 (class 1259 OID 16525)
-- Name: esia_manufacturer_class_class_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE esia_manufacturer_class_class_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- TOC entry 2523 (class 0 OID 0)
-- Dependencies: 204
-- Name: esia_manufacturer_class_class_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE esia_manufacturer_class_class_id_seq OWNED BY esia_php_class.class_id;


--
-- TOC entry 205 (class 1259 OID 16527)
-- Name: esia_memberof; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE esia_memberof (
    member_group_id integer NOT NULL,
    member_user_id integer NOT NULL
);


--
-- TOC entry 206 (class 1259 OID 16530)
-- Name: esia_model; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE esia_model (
    model_id bigint NOT NULL,
    model_name character varying(50),
    model_manufacturer_oid bigint,
    model_html_tpl character varying
);


--
-- TOC entry 207 (class 1259 OID 16536)
-- Name: esia_model_model_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE esia_model_model_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- TOC entry 2524 (class 0 OID 0)
-- Dependencies: 207
-- Name: esia_model_model_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE esia_model_model_id_seq OWNED BY esia_model.model_id;


--
-- TOC entry 208 (class 1259 OID 16538)
-- Name: esia_os; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE esia_os (
    os_id integer NOT NULL,
    os_name character varying(30),
    os_version character varying(20) NOT NULL,
    os_template_path character varying(200),
    os_manufacturer_oid bigint
);


--
-- TOC entry 209 (class 1259 OID 16541)
-- Name: esia_os_os_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE esia_os_os_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- TOC entry 2525 (class 0 OID 0)
-- Dependencies: 209
-- Name: esia_os_os_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE esia_os_os_id_seq OWNED BY esia_os.os_id;


--
-- TOC entry 210 (class 1259 OID 16543)
-- Name: esia_plugins; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE esia_plugins (
    plugin_id integer NOT NULL,
    plugin_name character varying(50),
    plugin_path character varying(150),
    plugin_type character varying(100),
    plugin_trap_oid character varying(150),
    plugin_default_parameter character varying(250),
    plugin_default_interval_time integer DEFAULT 300000,
    plugin_description text,
    plugin_delete boolean DEFAULT false NOT NULL,
    plugin_priority smallint DEFAULT 7,
    plugin_html_template character varying (250)
);


--
-- TOC entry 211 (class 1259 OID 16552)
-- Name: esia_plugin_plugin_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE esia_plugin_plugin_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- TOC entry 2526 (class 0 OID 0)
-- Dependencies: 211
-- Name: esia_plugin_plugin_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE esia_plugin_plugin_id_seq OWNED BY esia_plugins.plugin_id;


--
-- TOC entry 212 (class 1259 OID 16554)
-- Name: esia_privilege_grantedto; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE esia_privilege_grantedto (
    grant_group_id integer NOT NULL,
    grant_privilege_id integer NOT NULL,
    grant_acces integer DEFAULT 0
);


--
-- TOC entry 213 (class 1259 OID 16558)
-- Name: esia_privileges; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE esia_privileges (
    privilege_id integer NOT NULL,
    privilege_name character varying NOT NULL,
    privilege_site smallint DEFAULT 0 NOT NULL,
    privilege_description character varying(200)
);


--
-- TOC entry 214 (class 1259 OID 16565)
-- Name: esia_privilege_privilege_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE esia_privilege_privilege_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- TOC entry 2527 (class 0 OID 0)
-- Dependencies: 214
-- Name: esia_privilege_privilege_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE esia_privilege_privilege_id_seq OWNED BY esia_privileges.privilege_id;


--
-- TOC entry 215 (class 1259 OID 16567)
-- Name: esia_program; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE esia_program (
    program_id integer NOT NULL,
    program_name character varying(30),
    program_path character varying(150),
    program_default_parameter character varying(100)
);


--
-- TOC entry 216 (class 1259 OID 16570)
-- Name: esia_program_program_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE esia_program_program_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- TOC entry 2528 (class 0 OID 0)
-- Dependencies: 216
-- Name: esia_program_program_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE esia_program_program_id_seq OWNED BY esia_program.program_id;


--
-- TOC entry 217 (class 1259 OID 16572)
-- Name: esia_search; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE esia_search (
    search_keyword character varying(20) NOT NULL,
    search_description character varying(200),
    search_file character varying(100),
    search_function character varying(40),
    search_name character varying(40)
);


--
-- TOC entry 218 (class 1259 OID 16575)
-- Name: esia_service_pattern_included; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE esia_service_pattern_included (
    included_id bigint NOT NULL,
    included_name character varying(50),
    included_pattern_id integer NOT NULL,
    included_plugin_id integer,
    included_parameter character varying(300),
    included_interval integer,
    included_program_id integer,
    included_program_parameter character varying(250),
    included_unknown boolean,
    included_warning boolean,
    included_critical boolean,
    included_priority smallint DEFAULT 7
);


--
-- TOC entry 219 (class 1259 OID 16579)
-- Name: esia_service_patterns; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE esia_service_patterns (
    pattern_id integer NOT NULL,
    pattern_name character varying(50),
    pattern_description character varying(300)
);


--
-- TOC entry 220 (class 1259 OID 16582)
-- Name: esia_service_pending_execute; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE esia_service_pending_execute (
    pending_service_id bigint NOT NULL,
    pending_type character varying(10) DEFAULT 'ADD'::character varying
);


--
-- TOC entry 221 (class 1259 OID 16586)
-- Name: esia_service_response_program; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE esia_service_response_program (
    response_service_id bigint NOT NULL,
    response_program_id integer NOT NULL,
    response_parameter character varying(150),
    response_ok boolean,
    response_warning boolean,
    response_critical boolean,
    response_unknown boolean
);


--
-- TOC entry 222 (class 1259 OID 16589)
-- Name: esia_services; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE esia_services (
    service_plugin_id bigint NOT NULL,
    service_device_id bigint NOT NULL,
    service_interval_time bigint,
    service_parameter character varying(250),
    service_previous_state integer DEFAULT 0,
    service_last_exec_time timestamp without time zone,
    service_last_stdout text,
    service_id bigint NOT NULL,
    service_name character varying(100),
    service_time_added timestamp without time zone DEFAULT now(),
    service_delete boolean DEFAULT false NOT NULL,
    service_included_id integer,
    service_priority smallint DEFAULT 7
);


--
-- TOC entry 223 (class 1259 OID 16599)
-- Name: esia_services_service_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE esia_services_service_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- TOC entry 2529 (class 0 OID 0)
-- Dependencies: 223
-- Name: esia_services_service_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE esia_services_service_id_seq OWNED BY esia_services.service_id;


--
-- TOC entry 224 (class 1259 OID 16601)
-- Name: esia_switch; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE esia_switch (
    switch_device_id bigint NOT NULL,
    switch_model_id bigint,
    switch_class_id bigint,
    switch_os_id bigint
);


--
-- TOC entry 225 (class 1259 OID 16604)
-- Name: esia_template_template_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE esia_template_template_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- TOC entry 2530 (class 0 OID 0)
-- Dependencies: 225
-- Name: esia_template_template_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE esia_template_template_id_seq OWNED BY esia_service_patterns.pattern_id;


--
-- TOC entry 226 (class 1259 OID 16606)
-- Name: esia_theme; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE esia_theme (
    theme_id integer NOT NULL,
    theme_name character varying(20)
);


--
-- TOC entry 227 (class 1259 OID 16609)
-- Name: esia_theme_theme_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE esia_theme_theme_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- TOC entry 2531 (class 0 OID 0)
-- Dependencies: 227
-- Name: esia_theme_theme_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE esia_theme_theme_id_seq OWNED BY esia_theme.theme_id;


--
-- TOC entry 228 (class 1259 OID 16611)
-- Name: esia_tpl_service_sertpl_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE esia_tpl_service_sertpl_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- TOC entry 2532 (class 0 OID 0)
-- Dependencies: 228
-- Name: esia_tpl_service_sertpl_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE esia_tpl_service_sertpl_id_seq OWNED BY esia_service_pattern_included.included_id;


--
-- TOC entry 229 (class 1259 OID 16613)
-- Name: esia_users; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE esia_users (
    user_id integer NOT NULL,
    user_name character varying NOT NULL,
    user_password character varying(40),
    user_lang character varying(5),
    user_inscription_time timestamp without time zone DEFAULT now(),
    user_email character varying(50),
    user_change_password smallint DEFAULT 0,
    user_theme_id integer,
	user_tuto_view integer
);


--
-- TOC entry 230 (class 1259 OID 16621)
-- Name: esia_users_user_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE esia_users_user_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- TOC entry 2533 (class 0 OID 0)
-- Dependencies: 230
-- Name: esia_users_user_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE esia_users_user_id_seq OWNED BY esia_users.user_id;


--
-- TOC entry 231 (class 1259 OID 16623)
-- Name: esia_web_plugin; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE esia_web_plugin (
    web_id integer NOT NULL,
    web_name character varying(30) NOT NULL,
    web_dir_lang character varying(250),
    web_php_menu character varying(250),
    web_index_page character varying(30),
    web_admin_page character varying(100),
    web_activate boolean DEFAULT true,
    web_tpl_method character varying(20),
    web_plugin_apache_path character varying(20) NOT NULL,
    web_page_control character varying(50),
    web_show_main_menu boolean DEFAULT true,
    web_icon character varying(200)
);


--
-- TOC entry 232 (class 1259 OID 16628)
-- Name: esia_web_plugin_web_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE esia_web_plugin_web_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- TOC entry 2534 (class 0 OID 0)
-- Dependencies: 232
-- Name: esia_web_plugin_web_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE esia_web_plugin_web_id_seq OWNED BY esia_web_plugin.web_id;


--
-- TOC entry 233 (class 1259 OID 16630)
-- Name: esia_zone; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE esia_zone (
    zone_id integer NOT NULL,
    zone_name character varying(50),
    zone_abreviation character varying(10),
    zone_latitude real[],
    zone_longitude real[]
);


--
-- TOC entry 234 (class 1259 OID 16636)
-- Name: esia_zone_zone_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE esia_zone_zone_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- TOC entry 2535 (class 0 OID 0)
-- Dependencies: 234
-- Name: esia_zone_zone_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE esia_zone_zone_id_seq OWNED BY esia_zone.zone_id;


--
-- TOC entry 235 (class 1259 OID 16638)
-- Name: gesa_connected; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE gesa_connected (
    connected_gesa_id bigint NOT NULL,
    connected_device_id bigint NOT NULL
);


--
-- TOC entry 236 (class 1259 OID 16641)
-- Name: gesa_info; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE gesa_info (
    gesa_device_id bigint NOT NULL,
    gesa_max_slot integer,
    gesa_sn bigint,
	gesa_version_base character varying(10),
	gesa_version_nrpe character varying(10),
	gesa_version_plugin character varying(10),
	gesa_version_web character varying(10),
	gesa_repo_global character varying(100),
	gesa_repo_gesa character varying(100),
	gesa_last_update timestamp without time zone,
	gesa_rsbp character varying(10),
	gesa_local_ip inet
);


--
-- TOC entry 237 (class 1259 OID 16644)
-- Name: localization_images_image_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE localization_images_image_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- TOC entry 2536 (class 0 OID 0)
-- Dependencies: 237
-- Name: localization_images_image_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE localization_images_image_id_seq OWNED BY esia_localization_images.image_id;


--
-- TOC entry 238 (class 1259 OID 16646)
-- Name: rrd_plugins; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE rrd_plugins (
    rrd_plugin_id integer NOT NULL,
    rrd_type character varying(20),
    rrd_regex character varying(50),
    rrd_time integer,
    rrd_id integer NOT NULL,
    rrd_name character varying(30),
    rrd_min bigint,
    rrd_max bigint,
    rrd_vertical_label character varying(20),
    rrd_graph_type character varying(20),
    rrd_graph_color character varying(10),
    rrd_regex_threshold character varying(50),
    rrd_graph_num smallint,
	rrd_calc character varying
);


--
-- TOC entry 239 (class 1259 OID 16649)
-- Name: rrd_plugins_rrd_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE rrd_plugins_rrd_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- TOC entry 2537 (class 0 OID 0)
-- Dependencies: 239
-- Name: rrd_plugins_rrd_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE rrd_plugins_rrd_id_seq OWNED BY rrd_plugins.rrd_id;


--
-- TOC entry 240 (class 1259 OID 16651)
-- Name: sms_send; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE sms_send (
    sms_id integer NOT NULL,
    sms_to text,
    sms_message text,
    sms_date timestamp without time zone
);

--
-- TOC entry 241 (class 1259 OID 16657)
-- Name: sms_send_sms_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE sms_send_sms_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- TOC entry 2538 (class 0 OID 0)
-- Dependencies: 241
-- Name: sms_send_sms_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE sms_send_sms_id_seq OWNED BY sms_send.sms_id;


--
-- TOC entry 2128 (class 2604 OID 16659)
-- Name: building_id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_building ALTER COLUMN building_id SET DEFAULT nextval('esia_building_building_id_seq'::regclass);


--
-- TOC entry 2130 (class 2604 OID 16660)
-- Name: container_id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_container ALTER COLUMN container_id SET DEFAULT nextval('esia_container_container_id_seq'::regclass);


--
-- TOC entry 2131 (class 2604 OID 16661)
-- Name: container_type_id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_container_type ALTER COLUMN container_type_id SET DEFAULT nextval('esia_container_type_container_type_id_seq'::regclass);


--
-- TOC entry 2136 (class 2604 OID 16662)
-- Name: device_id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_device ALTER COLUMN device_id SET DEFAULT nextval('esia_device_device_id_seq'::regclass);


--
-- TOC entry 2137 (class 2604 OID 16663)
-- Name: type_id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_device_type ALTER COLUMN type_id SET DEFAULT nextval('esia_device_type_type_id_seq'::regclass);


--
-- TOC entry 2141 (class 2604 OID 16664)
-- Name: happen_id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_error_happen ALTER COLUMN happen_id SET DEFAULT nextval('esia_error_happen_happen_id_seq'::regclass);


--
-- TOC entry 2143 (class 2604 OID 16665)
-- Name: error_id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_errors ALTER COLUMN error_id SET DEFAULT nextval('esia_errors_error_id_seq'::regclass);


--
-- TOC entry 2144 (class 2604 OID 16666)
-- Name: floor_id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_floor ALTER COLUMN floor_id SET DEFAULT nextval('esia_floor_floor_id_seq'::regclass);


--
-- TOC entry 2145 (class 2604 OID 16667)
-- Name: group_id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_groups ALTER COLUMN group_id SET DEFAULT nextval('esia_groups_group_id_seq'::regclass);


--
-- TOC entry 2150 (class 2604 OID 16668)
-- Name: interface_id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_interface ALTER COLUMN interface_id SET DEFAULT nextval('esia_interface_interface_id_seq'::regclass);


--
-- TOC entry 2151 (class 2604 OID 16669)
-- Name: localization_id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_localization ALTER COLUMN localization_id SET DEFAULT nextval('esia_localization_localization_id_seq'::regclass);


--
-- TOC entry 2152 (class 2604 OID 16670)
-- Name: image_id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_localization_images ALTER COLUMN image_id SET DEFAULT nextval('localization_images_image_id_seq'::regclass);


--
-- TOC entry 2155 (class 2604 OID 16671)
-- Name: model_id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_model ALTER COLUMN model_id SET DEFAULT nextval('esia_model_model_id_seq'::regclass);


--
-- TOC entry 2156 (class 2604 OID 16672)
-- Name: os_id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_os ALTER COLUMN os_id SET DEFAULT nextval('esia_os_os_id_seq'::regclass);


--
-- TOC entry 2154 (class 2604 OID 16673)
-- Name: class_id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_php_class ALTER COLUMN class_id SET DEFAULT nextval('esia_manufacturer_class_class_id_seq'::regclass);


--
-- TOC entry 2160 (class 2604 OID 16674)
-- Name: plugin_id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_plugins ALTER COLUMN plugin_id SET DEFAULT nextval('esia_plugin_plugin_id_seq'::regclass);


--
-- TOC entry 2163 (class 2604 OID 16675)
-- Name: privilege_id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_privileges ALTER COLUMN privilege_id SET DEFAULT nextval('esia_privilege_privilege_id_seq'::regclass);


--
-- TOC entry 2164 (class 2604 OID 16676)
-- Name: program_id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_program ALTER COLUMN program_id SET DEFAULT nextval('esia_program_program_id_seq'::regclass);


--
-- TOC entry 2166 (class 2604 OID 16677)
-- Name: included_id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_service_pattern_included ALTER COLUMN included_id SET DEFAULT nextval('esia_tpl_service_sertpl_id_seq'::regclass);


--
-- TOC entry 2167 (class 2604 OID 16678)
-- Name: pattern_id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_service_patterns ALTER COLUMN pattern_id SET DEFAULT nextval('esia_template_template_id_seq'::regclass);


--
-- TOC entry 2173 (class 2604 OID 16679)
-- Name: service_id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_services ALTER COLUMN service_id SET DEFAULT nextval('esia_services_service_id_seq'::regclass);


--
-- TOC entry 2174 (class 2604 OID 16680)
-- Name: theme_id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_theme ALTER COLUMN theme_id SET DEFAULT nextval('esia_theme_theme_id_seq'::regclass);


--
-- TOC entry 2177 (class 2604 OID 16681)
-- Name: user_id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_users ALTER COLUMN user_id SET DEFAULT nextval('esia_users_user_id_seq'::regclass);


--
-- TOC entry 2180 (class 2604 OID 16682)
-- Name: web_id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_web_plugin ALTER COLUMN web_id SET DEFAULT nextval('esia_web_plugin_web_id_seq'::regclass);


--
-- TOC entry 2181 (class 2604 OID 16683)
-- Name: zone_id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_zone ALTER COLUMN zone_id SET DEFAULT nextval('esia_zone_zone_id_seq'::regclass);


--
-- TOC entry 2182 (class 2604 OID 16684)
-- Name: rrd_id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY rrd_plugins ALTER COLUMN rrd_id SET DEFAULT nextval('rrd_plugins_rrd_id_seq'::regclass);


--
-- TOC entry 2183 (class 2604 OID 16685)
-- Name: sms_id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY sms_send ALTER COLUMN sms_id SET DEFAULT nextval('sms_send_sms_id_seq'::regclass);


--
-- TOC entry 2236 (class 2606 OID 16687)
-- Name: access_PrimaryKey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_group_device_access
    ADD CONSTRAINT "access_PrimaryKey" PRIMARY KEY (access_group_id, access_device_id);


--
-- TOC entry 2185 (class 2606 OID 16689)
-- Name: building_PrimaryKey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_building
    ADD CONSTRAINT "building_PrimaryKey" PRIMARY KEY (building_id);


-- TOC entry 2271 (class 2606 OID 16693)
-- Name: class_PrimaryKey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_php_class
    ADD CONSTRAINT "class_PrimaryKey" PRIMARY KEY (class_id);


--
-- TOC entry 2190 (class 2606 OID 16695)
-- Name: config_primary_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_configuration
    ADD CONSTRAINT config_primary_key PRIMARY KEY (config_key);


--
-- TOC entry 2192 (class 2606 OID 16697)
-- Name: container_Primarykey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_container
    ADD CONSTRAINT "container_Primarykey" PRIMARY KEY (container_id);


--
-- TOC entry 2194 (class 2606 OID 16699)
-- Name: container_name_Unique; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_container
    ADD CONSTRAINT "container_name_Unique" UNIQUE (container_name);


--
-- TOC entry 2197 (class 2606 OID 16701)
-- Name: container_type_PrimaryKey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_container_type
    ADD CONSTRAINT "container_type_PrimaryKey" PRIMARY KEY (container_type_id);


--
-- TOC entry 2199 (class 2606 OID 16703)
-- Name: device_PrimaryKey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_device
    ADD CONSTRAINT "device_PrimaryKey" PRIMARY KEY (device_id);


--
-- TOC entry 2206 (class 2606 OID 16705)
-- Name: device_name_unique; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_device
    ADD CONSTRAINT device_name_unique UNIQUE (device_name);


--
-- TOC entry 2228 (class 2606 OID 16707)
-- Name: error_name_unique; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_errors
    ADD CONSTRAINT error_name_unique UNIQUE (error_name);


--
-- TOC entry 2230 (class 2606 OID 16709)
-- Name: error_primaryKey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_errors
    ADD CONSTRAINT "error_primaryKey" PRIMARY KEY (error_id);


--
-- TOC entry 2258 (class 2606 OID 16711)
-- Name: esia_mac_primaryKey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_mac
    ADD CONSTRAINT "esia_mac_primaryKey" PRIMARY KEY (mac);


--
-- TOC entry 2299 (class 2606 OID 16713)
-- Name: esia_programPrimaryKey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_program
    ADD CONSTRAINT "esia_programPrimaryKey" PRIMARY KEY (program_id);


--
-- TOC entry 2312 (class 2606 OID 16715)
-- Name: esia_response_PrimaryKey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_service_response_program
    ADD CONSTRAINT "esia_response_PrimaryKey" PRIMARY KEY (response_service_id, response_program_id);


--
-- TOC entry 2210 (class 2606 OID 16717)
-- Name: esia_stored_PrimaryKey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_device_stored_container
    ADD CONSTRAINT "esia_stored_PrimaryKey" PRIMARY KEY (stored_device_id, stored_container_id);


--
-- TOC entry 2324 (class 2606 OID 16719)
-- Name: esia_theme_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_theme
    ADD CONSTRAINT esia_theme_pkey PRIMARY KEY (theme_id);


--
-- TOC entry 2212 (class 2606 OID 16721)
-- Name: esia_type_primaryKey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_device_type
    ADD CONSTRAINT "esia_type_primaryKey" PRIMARY KEY (type_id);


--
-- TOC entry 2232 (class 2606 OID 16723)
-- Name: floor_PrimaryKey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_floor
    ADD CONSTRAINT "floor_PrimaryKey" PRIMARY KEY (floor_id);


--
-- TOC entry 2343 (class 2606 OID 16725)
-- Name: gesa_connected_PrimaryKey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY gesa_connected
    ADD CONSTRAINT "gesa_connected_PrimaryKey" PRIMARY KEY (connected_gesa_id, connected_device_id);


--
-- TOC entry 2345 (class 2606 OID 16727)
-- Name: gesa_primaryKey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY gesa_info
    ADD CONSTRAINT "gesa_primaryKey" PRIMARY KEY (gesa_device_id);


--
-- TOC entry 2291 (class 2606 OID 16729)
-- Name: grantedto_PrimaryKey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_privilege_grantedto
    ADD CONSTRAINT "grantedto_PrimaryKey" PRIMARY KEY (grant_group_id, grant_privilege_id);


--
-- TOC entry 2241 (class 2606 OID 16731)
-- Name: group_name_unique; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_groups
    ADD CONSTRAINT group_name_unique UNIQUE (group_name);


--
-- TOC entry 2243 (class 2606 OID 16733)
-- Name: groups_PrimaryKey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_groups
    ADD CONSTRAINT "groups_PrimaryKey" PRIMARY KEY (group_id);


--
-- TOC entry 2224 (class 2606 OID 16735)
-- Name: happen_primaryKey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_error_happen
    ADD CONSTRAINT "happen_primaryKey" PRIMARY KEY (happen_id);


--
-- TOC entry 2248 (class 2606 OID 16737)
-- Name: interface_primaryKey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_interface
    ADD CONSTRAINT "interface_primaryKey" PRIMARY KEY (interface_id);


--
-- TOC entry 2251 (class 2606 OID 16739)
-- Name: localization_PrimaryKey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_localization
    ADD CONSTRAINT "localization_PrimaryKey" PRIMARY KEY (localization_id);


--
-- TOC entry 2256 (class 2606 OID 16741)
-- Name: localization_image_primaryKey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_localization_images
    ADD CONSTRAINT "localization_image_primaryKey" PRIMARY KEY (image_id);


--
-- TOC entry 2260 (class 2606 OID 16743)
-- Name: mac_address_primaryKey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_mac_address
    ADD CONSTRAINT "mac_address_primaryKey" PRIMARY KEY (mac_address, mac_interface_id, mac_vlan_id);


--
-- TOC entry 2267 (class 2606 OID 16745)
-- Name: manufacturer_name_unique; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_manufacturer
    ADD CONSTRAINT manufacturer_name_unique UNIQUE (manufacturer_name);


--
-- TOC entry 2269 (class 2606 OID 16747)
-- Name: manufacturer_primarykey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_manufacturer
    ADD CONSTRAINT manufacturer_primarykey PRIMARY KEY (manufacturer_oid);


--
-- TOC entry 2276 (class 2606 OID 16749)
-- Name: memberof_PrimaryKey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_memberof
    ADD CONSTRAINT "memberof_PrimaryKey" PRIMARY KEY (member_group_id, member_user_id);


--
-- TOC entry 2278 (class 2606 OID 16751)
-- Name: model_name_unique; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_model
    ADD CONSTRAINT model_name_unique UNIQUE (model_name);


--
-- TOC entry 2280 (class 2606 OID 16753)
-- Name: model_primaryKey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_model
    ADD CONSTRAINT "model_primaryKey" PRIMARY KEY (model_id);


--
-- TOC entry 2282 (class 2606 OID 16755)
-- Name: os_primaryKey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_os
    ADD CONSTRAINT "os_primaryKey" PRIMARY KEY (os_id);


--
-- TOC entry 2310 (class 2606 OID 16757)
-- Name: pending_primary_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_service_pending_execute
    ADD CONSTRAINT pending_primary_key PRIMARY KEY (pending_service_id);


--
-- TOC entry 2286 (class 2606 OID 16759)
-- Name: plugin_name_unique; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_plugins
    ADD CONSTRAINT plugin_name_unique UNIQUE (plugin_name);


--
-- TOC entry 2288 (class 2606 OID 16761)
-- Name: plugin_primaryKey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_plugins
    ADD CONSTRAINT "plugin_primaryKey" PRIMARY KEY (plugin_id);


--
-- TOC entry 2293 (class 2606 OID 16763)
-- Name: privilege_PrimaryKey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_privileges
    ADD CONSTRAINT "privilege_PrimaryKey" PRIMARY KEY (privilege_id);


--
-- TOC entry 2297 (class 2606 OID 16765)
-- Name: privilege_name_unique; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_privileges
    ADD CONSTRAINT privilege_name_unique UNIQUE (privilege_name);


--
-- TOC entry 2347 (class 2606 OID 16767)
-- Name: rrd_Primarykey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY rrd_plugins
    ADD CONSTRAINT "rrd_Primarykey" PRIMARY KEY (rrd_id);


--
-- TOC entry 2301 (class 2606 OID 16769)
-- Name: search_PrimaryKey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_search
    ADD CONSTRAINT "search_PrimaryKey" PRIMARY KEY (search_keyword);


--
-- TOC entry 2304 (class 2606 OID 16771)
-- Name: sertpl_primaryKey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_service_pattern_included
    ADD CONSTRAINT "sertpl_primaryKey" PRIMARY KEY (included_id);


--
-- TOC entry 2317 (class 2606 OID 16773)
-- Name: service_primarKey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_services
    ADD CONSTRAINT "service_primarKey" PRIMARY KEY (service_id);


--
-- TOC entry 2349 (class 2606 OID 16775)
-- Name: sms_primaryKey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY sms_send
    ADD CONSTRAINT "sms_primaryKey" PRIMARY KEY (sms_id);


--
-- TOC entry 2322 (class 2606 OID 16777)
-- Name: switch_primaryKey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_switch
    ADD CONSTRAINT "switch_primaryKey" PRIMARY KEY (switch_device_id);


--
-- TOC entry 2306 (class 2606 OID 16779)
-- Name: template_name_unique; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_service_patterns
    ADD CONSTRAINT template_name_unique UNIQUE (pattern_name);


--
-- TOC entry 2308 (class 2606 OID 16781)
-- Name: template_primary_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_service_patterns
    ADD CONSTRAINT template_primary_key PRIMARY KEY (pattern_id);


--
-- TOC entry 2217 (class 2606 OID 16783)
-- Name: type_name_unique; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_device_type
    ADD CONSTRAINT type_name_unique UNIQUE (type_name);


--
-- TOC entry 2326 (class 2606 OID 16785)
-- Name: user_PrimaryKey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_users
    ADD CONSTRAINT "user_PrimaryKey" PRIMARY KEY (user_id);


--
-- TOC entry 2331 (class 2606 OID 16787)
-- Name: user_name_Unique; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_users
    ADD CONSTRAINT "user_name_Unique" UNIQUE (user_name);


--
-- TOC entry 2265 (class 2606 OID 16789)
-- Name: vendor_primaryKey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_mac_address_vendor
    ADD CONSTRAINT "vendor_primaryKey" PRIMARY KEY (vendor_mac_address);


--
-- TOC entry 2335 (class 2606 OID 16791)
-- Name: web_primaryKey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_web_plugin
    ADD CONSTRAINT "web_primaryKey" PRIMARY KEY (web_id);


--
-- TOC entry 2337 (class 2606 OID 16793)
-- Name: zone_PrimaryKey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_zone
    ADD CONSTRAINT "zone_PrimaryKey" PRIMARY KEY (zone_id);


--
-- TOC entry 2341 (class 2606 OID 16795)
-- Name: zone_name_unique; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_zone
    ADD CONSTRAINT zone_name_unique UNIQUE (zone_name);


--
-- TOC entry 2237 (class 1259 OID 16796)
-- Name: access_index; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX access_index ON esia_group_device_access USING btree (access_group_id, access_device_id);


--
-- TOC entry 2186 (class 1259 OID 16797)
-- Name: building_index_building_abreviation; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX building_index_building_abreviation ON esia_building USING btree (building_abreviation);


--
-- TOC entry 2187 (class 1259 OID 16798)
-- Name: building_index_building_zone; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX building_index_building_zone ON esia_building USING btree (building_zone_id);


--
-- TOC entry 2188 (class 1259 OID 16799)
-- Name: building_index_id; Type: INDEX; Schema: public; Owner: -
--

CREATE UNIQUE INDEX building_index_id ON esia_building USING btree (building_id);


--
-- TOC entry 2200 (class 1259 OID 16800)
-- Name: device_index_device_description; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX device_index_device_description ON esia_device USING btree (device_description NULLS FIRST);


--
-- TOC entry 2201 (class 1259 OID 16801)
-- Name: device_index_device_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX device_index_device_id ON esia_device USING btree (device_id);


--
-- TOC entry 2202 (class 1259 OID 16802)
-- Name: device_index_device_name; Type: INDEX; Schema: public; Owner: -
--

CREATE UNIQUE INDEX device_index_device_name ON esia_device USING btree (device_name);


--
-- TOC entry 2203 (class 1259 OID 16803)
-- Name: device_index_device_type; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX device_index_device_type ON esia_device USING btree (device_type);


--
-- TOC entry 2204 (class 1259 OID 16804)
-- Name: device_index_group_name; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX device_index_group_name ON esia_device USING btree (device_group_name);


--
-- TOC entry 2225 (class 1259 OID 16805)
-- Name: error_index_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX error_index_id ON esia_errors USING btree (error_id);


--
-- TOC entry 2226 (class 1259 OID 16806)
-- Name: error_index_name; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX error_index_name ON esia_errors USING btree (error_name);


--
-- TOC entry 2313 (class 1259 OID 16807)
-- Name: exe_index_device_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX exe_index_device_id ON esia_services USING btree (service_device_id);


--
-- TOC entry 2314 (class 1259 OID 16808)
-- Name: exe_index_plugin_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX exe_index_plugin_id ON esia_services USING btree (service_plugin_id);


--
-- TOC entry 2272 (class 1259 OID 16809)
-- Name: fki_class_foreignKey_esia_device_type; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX "fki_class_foreignKey_esia_device_type" ON esia_php_class USING btree (class_type);


--
-- TOC entry 2273 (class 1259 OID 16810)
-- Name: fki_class_foreignKey_manufacturer_oid; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX "fki_class_foreignKey_manufacturer_oid" ON esia_php_class USING btree (class_manufacturer_oid);


--
-- TOC entry 2195 (class 1259 OID 16811)
-- Name: fki_container_foreignKey_container_type; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX "fki_container_foreignKey_container_type" ON esia_container USING btree (container_type);


--
-- TOC entry 2302 (class 1259 OID 16812)
-- Name: fki_included_ForeignKay_program_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX "fki_included_ForeignKay_program_id" ON esia_service_pattern_included USING btree (included_program_id);


--
-- TOC entry 2249 (class 1259 OID 16813)
-- Name: fki_localization_ForeignKey_container_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX "fki_localization_ForeignKey_container_id" ON esia_localization USING btree (localization_container_id);


--
-- TOC entry 2315 (class 1259 OID 16814)
-- Name: fki_service_foreignkey_pattern_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX fki_service_foreignkey_pattern_id ON esia_services USING btree (service_included_id);


--
-- TOC entry 2318 (class 1259 OID 16815)
-- Name: fki_switch_foreignKey_class_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX "fki_switch_foreignKey_class_id" ON esia_switch USING btree (switch_class_id);


--
-- TOC entry 2319 (class 1259 OID 16816)
-- Name: fki_switch_foreignKey_model_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX "fki_switch_foreignKey_model_id" ON esia_switch USING btree (switch_model_id);


--
-- TOC entry 2320 (class 1259 OID 16817)
-- Name: fki_switch_foreignKey_os_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX "fki_switch_foreignKey_os_id" ON esia_switch USING btree (switch_os_id);


--
-- TOC entry 2233 (class 1259 OID 16818)
-- Name: floor_index_building_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX floor_index_building_id ON esia_floor USING btree (floor_building_id);


--
-- TOC entry 2234 (class 1259 OID 16819)
-- Name: floor_index_floor_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX floor_index_floor_id ON esia_floor USING btree (floor_id);


--
-- TOC entry 2289 (class 1259 OID 16820)
-- Name: grant_index; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX grant_index ON esia_privilege_grantedto USING btree (grant_group_id, grant_privilege_id);


--
-- TOC entry 2238 (class 1259 OID 16821)
-- Name: group_index_group_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX group_index_group_id ON esia_groups USING btree (group_id);


--
-- TOC entry 2239 (class 1259 OID 16822)
-- Name: group_index_name; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX group_index_name ON esia_groups USING btree (group_name);


--
-- TOC entry 2218 (class 1259 OID 16823)
-- Name: happen_index_acquitte; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX happen_index_acquitte ON esia_error_happen USING btree (happen_acquitte);


--
-- TOC entry 2219 (class 1259 OID 16824)
-- Name: happen_index_device_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX happen_index_device_id ON esia_error_happen USING btree (happen_device_id);


--
-- TOC entry 2220 (class 1259 OID 16825)
-- Name: happen_index_error_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX happen_index_error_id ON esia_error_happen USING btree (happen_error_id);


--
-- TOC entry 2221 (class 1259 OID 16826)
-- Name: happen_index_interface_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX happen_index_interface_id ON esia_error_happen USING btree (happen_interface_id);


--
-- TOC entry 2222 (class 1259 OID 16827)
-- Name: happen_index_service_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX happen_index_service_id ON esia_error_happen USING btree (happen_service_id);


--
-- TOC entry 2244 (class 1259 OID 16828)
-- Name: interface_index_device_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX interface_index_device_id ON esia_interface USING btree (interface_device_id);


--
-- TOC entry 2245 (class 1259 OID 16829)
-- Name: interface_index_name; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX interface_index_name ON esia_interface USING btree (interface_name);


--
-- TOC entry 2246 (class 1259 OID 16830)
-- Name: interface_index_plug; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX interface_index_plug ON esia_interface USING btree (interface_plug);


--
-- TOC entry 2252 (class 1259 OID 16831)
-- Name: localization_index_device_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX localization_index_device_id ON esia_localization USING btree (localization_device_id);


--
-- TOC entry 2253 (class 1259 OID 16832)
-- Name: localization_index_floor_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX localization_index_floor_id ON esia_localization USING btree (localization_floor_id);


--
-- TOC entry 2254 (class 1259 OID 16833)
-- Name: localization_index_id; Type: INDEX; Schema: public; Owner: -
--

CREATE UNIQUE INDEX localization_index_id ON esia_localization USING btree (localization_id);


--
-- TOC entry 2261 (class 1259 OID 16834)
-- Name: mac_index_interface_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX mac_index_interface_id ON esia_mac_address USING btree (mac_interface_id);


--
-- TOC entry 2262 (class 1259 OID 16835)
-- Name: mac_index_ip_address; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX mac_index_ip_address ON esia_mac_address USING btree (mac_ip_address);


--
-- TOC entry 2263 (class 1259 OID 16836)
-- Name: mac_index_mac_address; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX mac_index_mac_address ON esia_mac_address USING btree (mac_address);


--
-- TOC entry 2274 (class 1259 OID 16837)
-- Name: member_index; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX member_index ON esia_memberof USING btree (member_group_id, member_user_id);


--
-- TOC entry 2283 (class 1259 OID 16838)
-- Name: plugin_index_plugin_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX plugin_index_plugin_id ON esia_plugins USING btree (plugin_id);


--
-- TOC entry 2284 (class 1259 OID 16839)
-- Name: plugin_index_plugin_name; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX plugin_index_plugin_name ON esia_plugins USING btree (plugin_name);


--
-- TOC entry 2294 (class 1259 OID 16840)
-- Name: privilege_index_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX privilege_index_id ON esia_privileges USING btree (privilege_id);


--
-- TOC entry 2295 (class 1259 OID 16841)
-- Name: privilege_index_name; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX privilege_index_name ON esia_privileges USING btree (privilege_name);


--
-- TOC entry 2213 (class 1259 OID 16842)
-- Name: type_index_name; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX type_index_name ON esia_device_type USING btree (type_name);


--
-- TOC entry 2214 (class 1259 OID 16843)
-- Name: type_index_type_id; Type: INDEX; Schema: public; Owner: -
--

CREATE UNIQUE INDEX type_index_type_id ON esia_device_type USING btree (type_id);


--
-- TOC entry 2215 (class 1259 OID 16844)
-- Name: type_index_web_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX type_index_web_id ON esia_device_type USING btree (type_web_id);


--
-- TOC entry 2327 (class 1259 OID 16845)
-- Name: user_index_email; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX user_index_email ON esia_users USING btree (user_email);


--
-- TOC entry 2328 (class 1259 OID 16846)
-- Name: user_index_user_id; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX user_index_user_id ON esia_users USING btree (user_id);


--
-- TOC entry 2329 (class 1259 OID 16847)
-- Name: user_index_user_name; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX user_index_user_name ON esia_users USING btree (user_name);


--
-- TOC entry 2332 (class 1259 OID 16848)
-- Name: web_index_name; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX web_index_name ON esia_web_plugin USING btree (web_name);


--
-- TOC entry 2333 (class 1259 OID 16849)
-- Name: web_index_web_id; Type: INDEX; Schema: public; Owner: -
--

CREATE UNIQUE INDEX web_index_web_id ON esia_web_plugin USING btree (web_id);


--
-- TOC entry 2338 (class 1259 OID 16850)
-- Name: zone_index_zone_id; Type: INDEX; Schema: public; Owner: -
--

CREATE UNIQUE INDEX zone_index_zone_id ON esia_zone USING btree (zone_id);


--
-- TOC entry 2339 (class 1259 OID 16851)
-- Name: zone_index_zone_name; Type: INDEX; Schema: public; Owner: -
--

CREATE UNIQUE INDEX zone_index_zone_name ON esia_zone USING btree (zone_name);


--
-- TOC entry 2394 (class 2620 OID 16852)
-- Name: deleteDevice; Type: TRIGGER; Schema: public; Owner: -
--

CREATE TRIGGER "deleteDevice" BEFORE DELETE ON esia_device FOR EACH ROW EXECUTE PROCEDURE trigger_delete_device();


--
-- TOC entry 2395 (class 2620 OID 16853)
-- Name: deleteService; Type: TRIGGER; Schema: public; Owner: -
--

CREATE TRIGGER "deleteService" BEFORE DELETE ON esia_services FOR EACH ROW EXECUTE PROCEDURE trigger_delete_service();


--
-- TOC entry 2362 (class 2606 OID 16854)
-- Name: access_ForeignKey_device_id; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_group_device_access
    ADD CONSTRAINT "access_ForeignKey_device_id" FOREIGN KEY (access_device_id) REFERENCES esia_device(device_id);


--
-- TOC entry 2363 (class 2606 OID 16859)
-- Name: access_ForeignKey_group_id; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_group_device_access
    ADD CONSTRAINT "access_ForeignKey_group_id" FOREIGN KEY (access_group_id) REFERENCES esia_groups(group_id);


--
-- TOC entry 2350 (class 2606 OID 16864)
-- Name: building_ForeignKey_zone_id; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_building
    ADD CONSTRAINT "building_ForeignKey_zone_id" FOREIGN KEY (building_zone_id) REFERENCES esia_zone(zone_id);


--
-- TOC entry 2353 (class 2606 OID 16869)
-- Name: cacti_foreign_key_device_id; Type: FK CONSTRAINT; Schema: public; Owner: -
--


--
-- TOC entry 2370 (class 2606 OID 16874)
-- Name: class_foreignKey_manufacturer_oid; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_php_class
    ADD CONSTRAINT "class_foreignKey_manufacturer_oid" FOREIGN KEY (class_manufacturer_oid) REFERENCES esia_manufacturer(manufacturer_oid);


--
-- TOC entry 2351 (class 2606 OID 16879)
-- Name: container_foreignKey_container_type; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_container
    ADD CONSTRAINT "container_foreignKey_container_type" FOREIGN KEY (container_type) REFERENCES esia_container_type(container_type_id);


--
-- TOC entry 2352 (class 2606 OID 16884)
-- Name: device_ForeignKey_type_name; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_device
    ADD CONSTRAINT "device_ForeignKey_type_name" FOREIGN KEY (device_type) REFERENCES esia_device_type(type_name);


--
-- TOC entry 2380 (class 2606 OID 16889)
-- Name: esia_response_ForeignKey_program_id; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_service_response_program
    ADD CONSTRAINT "esia_response_ForeignKey_program_id" FOREIGN KEY (response_program_id) REFERENCES esia_program(program_id);


--
-- TOC entry 2381 (class 2606 OID 16894)
-- Name: esia_response_ForeignKey_service_id; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_service_response_program
    ADD CONSTRAINT "esia_response_ForeignKey_service_id" FOREIGN KEY (response_service_id) REFERENCES esia_services(service_id);


--
-- TOC entry 2361 (class 2606 OID 16899)
-- Name: floor_ForeignKey_building_id; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_floor
    ADD CONSTRAINT "floor_ForeignKey_building_id" FOREIGN KEY (floor_building_id) REFERENCES esia_building(building_id);


--
-- TOC entry 2390 (class 2606 OID 16904)
-- Name: gesa_connected_ForeignKey_device_id; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY gesa_connected
    ADD CONSTRAINT "gesa_connected_ForeignKey_device_id" FOREIGN KEY (connected_device_id) REFERENCES esia_device(device_id);


--
-- TOC entry 2391 (class 2606 OID 16909)
-- Name: gesa_connected_ForeignKey_gesa; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY gesa_connected
    ADD CONSTRAINT "gesa_connected_ForeignKey_gesa" FOREIGN KEY (connected_gesa_id) REFERENCES esia_device(device_id);


--
-- TOC entry 2392 (class 2606 OID 16914)
-- Name: gesa_foreignKey_device_id; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY gesa_info
    ADD CONSTRAINT "gesa_foreignKey_device_id" FOREIGN KEY (gesa_device_id) REFERENCES esia_device(device_id);


--
-- TOC entry 2375 (class 2606 OID 16919)
-- Name: grant_ForeignKey_group_id; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_privilege_grantedto
    ADD CONSTRAINT "grant_ForeignKey_group_id" FOREIGN KEY (grant_group_id) REFERENCES esia_groups(group_id);


--
-- TOC entry 2376 (class 2606 OID 16924)
-- Name: grant_ForeignKey_privilege_id; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_privilege_grantedto
    ADD CONSTRAINT "grant_ForeignKey_privilege_id" FOREIGN KEY (grant_privilege_id) REFERENCES esia_privileges(privilege_id);


--
-- TOC entry 2357 (class 2606 OID 16929)
-- Name: happen_ForeignKey_error_id; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_error_happen
    ADD CONSTRAINT "happen_ForeignKey_error_id" FOREIGN KEY (happen_error_id) REFERENCES esia_errors(error_id);


--
-- TOC entry 2358 (class 2606 OID 16934)
-- Name: happen_ForeignKey_interface_id; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_error_happen
    ADD CONSTRAINT "happen_ForeignKey_interface_id" FOREIGN KEY (happen_interface_id) REFERENCES esia_interface(interface_id);


--
-- TOC entry 2359 (class 2606 OID 16939)
-- Name: happen_ForeignKey_service_id; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_error_happen
    ADD CONSTRAINT "happen_ForeignKey_service_id" FOREIGN KEY (happen_service_id) REFERENCES esia_services(service_id);


--
-- TOC entry 2360 (class 2606 OID 16944)
-- Name: happen_foreignKey_device_id; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_error_happen
    ADD CONSTRAINT "happen_foreignKey_device_id" FOREIGN KEY (happen_device_id) REFERENCES esia_device(device_id);


--
-- TOC entry 2377 (class 2606 OID 16949)
-- Name: included_ForeignKay_program_id; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_service_pattern_included
    ADD CONSTRAINT "included_ForeignKay_program_id" FOREIGN KEY (included_program_id) REFERENCES esia_program(program_id);


--
-- TOC entry 2364 (class 2606 OID 16954)
-- Name: interface_foreignKey_device_id; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_interface
    ADD CONSTRAINT "interface_foreignKey_device_id" FOREIGN KEY (interface_device_id) REFERENCES esia_device(device_id);


--
-- TOC entry 2365 (class 2606 OID 16959)
-- Name: localization_ForeignKey_container_id; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_localization
    ADD CONSTRAINT "localization_ForeignKey_container_id" FOREIGN KEY (localization_container_id) REFERENCES esia_container(container_id);


--
-- TOC entry 2366 (class 2606 OID 16964)
-- Name: localization_ForeignKey_device; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_localization
    ADD CONSTRAINT "localization_ForeignKey_device" FOREIGN KEY (localization_device_id) REFERENCES esia_device(device_id);


--
-- TOC entry 2367 (class 2606 OID 16969)
-- Name: localization_ForeignKey_floor; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_localization
    ADD CONSTRAINT "localization_ForeignKey_floor" FOREIGN KEY (localization_floor_id) REFERENCES esia_floor(floor_id);


--
-- TOC entry 2368 (class 2606 OID 16974)
-- Name: localization_foreignKey_image_id; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_localization
    ADD CONSTRAINT "localization_foreignKey_image_id" FOREIGN KEY (localization_image_id) REFERENCES esia_localization_images(image_id);


--
-- TOC entry 2369 (class 2606 OID 16979)
-- Name: mac_foreignKey_interface_id; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_mac_address
    ADD CONSTRAINT "mac_foreignKey_interface_id" FOREIGN KEY (mac_interface_id) REFERENCES esia_interface(interface_id);


--
-- TOC entry 2371 (class 2606 OID 16984)
-- Name: memberof_ForeignKey_group_id; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_memberof
    ADD CONSTRAINT "memberof_ForeignKey_group_id" FOREIGN KEY (member_group_id) REFERENCES esia_groups(group_id);


--
-- TOC entry 2372 (class 2606 OID 16989)
-- Name: memberof_ForeignKey_user_id; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_memberof
    ADD CONSTRAINT "memberof_ForeignKey_user_id" FOREIGN KEY (member_user_id) REFERENCES esia_users(user_id);


--
-- TOC entry 2373 (class 2606 OID 16994)
-- Name: model_foreingKey_manufacturer_oid; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_model
    ADD CONSTRAINT "model_foreingKey_manufacturer_oid" FOREIGN KEY (model_manufacturer_oid) REFERENCES esia_manufacturer(manufacturer_oid);


--
-- TOC entry 2374 (class 2606 OID 16999)
-- Name: os_foreignKey_manufacturer_oid; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_os
    ADD CONSTRAINT "os_foreignKey_manufacturer_oid" FOREIGN KEY (os_manufacturer_oid) REFERENCES esia_manufacturer(manufacturer_oid);


--
-- TOC entry 2393 (class 2606 OID 17004)
-- Name: rrd_plugin_ForeignKey_plugin_id; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY rrd_plugins
    ADD CONSTRAINT "rrd_plugin_ForeignKey_plugin_id" FOREIGN KEY (rrd_plugin_id) REFERENCES esia_plugins(plugin_id) ON DELETE CASCADE;


--
-- TOC entry 2378 (class 2606 OID 17009)
-- Name: sertpl_foreignKey_plugin_id; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_service_pattern_included
    ADD CONSTRAINT "sertpl_foreignKey_plugin_id" FOREIGN KEY (included_plugin_id) REFERENCES esia_plugins(plugin_id) ON DELETE CASCADE;


--
-- TOC entry 2379 (class 2606 OID 17014)
-- Name: sertpl_foreign_key_template_id; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_service_pattern_included
    ADD CONSTRAINT sertpl_foreign_key_template_id FOREIGN KEY (included_pattern_id) REFERENCES esia_service_patterns(pattern_id);


--
-- TOC entry 2382 (class 2606 OID 17019)
-- Name: service_ForeignKey_device_id; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_services
    ADD CONSTRAINT "service_ForeignKey_device_id" FOREIGN KEY (service_device_id) REFERENCES esia_device(device_id);


--
-- TOC entry 2383 (class 2606 OID 17024)
-- Name: service_ForeignKey_included_id; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_services
    ADD CONSTRAINT "service_ForeignKey_included_id" FOREIGN KEY (service_included_id) REFERENCES esia_service_pattern_included(included_id);


--
-- TOC entry 2384 (class 2606 OID 17029)
-- Name: service_ForeignKey_plugin _id; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_services
    ADD CONSTRAINT "service_ForeignKey_plugin _id" FOREIGN KEY (service_plugin_id) REFERENCES esia_plugins(plugin_id);


--
-- TOC entry 2354 (class 2606 OID 17034)
-- Name: stored_foreignKey_container_id; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_device_stored_container
    ADD CONSTRAINT "stored_foreignKey_container_id" FOREIGN KEY (stored_container_id) REFERENCES esia_container(container_id);


--
-- TOC entry 2355 (class 2606 OID 17039)
-- Name: stored_foreignKey_device_id; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_device_stored_container
    ADD CONSTRAINT "stored_foreignKey_device_id" FOREIGN KEY (stored_device_id) REFERENCES esia_device(device_id);


--
-- TOC entry 2385 (class 2606 OID 17044)
-- Name: switch_foreignKey_class_id; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_switch
    ADD CONSTRAINT "switch_foreignKey_class_id" FOREIGN KEY (switch_class_id) REFERENCES esia_php_class(class_id);


--
-- TOC entry 2386 (class 2606 OID 17049)
-- Name: switch_foreignKey_device_id; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_switch
    ADD CONSTRAINT "switch_foreignKey_device_id" FOREIGN KEY (switch_device_id) REFERENCES esia_device(device_id);


--
-- TOC entry 2387 (class 2606 OID 17054)
-- Name: switch_foreignKey_model_id; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_switch
    ADD CONSTRAINT "switch_foreignKey_model_id" FOREIGN KEY (switch_model_id) REFERENCES esia_model(model_id);


--
-- TOC entry 2388 (class 2606 OID 17059)
-- Name: switch_foreignKey_os_id; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_switch
    ADD CONSTRAINT "switch_foreignKey_os_id" FOREIGN KEY (switch_os_id) REFERENCES esia_os(os_id);


--
-- TOC entry 2356 (class 2606 OID 17064)
-- Name: type_web_id_ForeignKey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_device_type
    ADD CONSTRAINT "type_web_id_ForeignKey" FOREIGN KEY (type_web_id) REFERENCES esia_web_plugin(web_id);


--
-- TOC entry 2389 (class 2606 OID 17069)
-- Name: user_foreignKey_theme_id; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY esia_users
    ADD CONSTRAINT "user_foreignKey_theme_id" FOREIGN KEY (user_theme_id) REFERENCES esia_theme(theme_id);

ALTER TABLE esia_error_happen
  ADD CONSTRAINT "happen_ForeignKey_user_id" FOREIGN KEY (happen_user_id) REFERENCES esia_users (user_id) ON UPDATE NO ACTION ON DELETE NO ACTION;

CREATE INDEX "happen_ForeignKey_user_id" ON esia_error_happen(happen_user_id);
-- Completed on 2015-07-29 14:08:40 CEST

--
-- PostgreSQL database dump complete
--

CREATE OR REPLACE FUNCTION getuseraccessnode(userid integer)
  RETURNS SETOF integer AS
$BODY$
    DECLARE
        v_service integer;
        BEGIN
        RETURN QUERY SELECT access_device_id
            FROM esia_group_device_access
            JOIN esia_groups ON access_group_id = group_id
            JOIN esia_memberof ON member_group_id = group_id
            WHERE member_user_id=userid;
   END;
$BODY$
  LANGUAGE plpgsql VOLATILE
  COST 100
  ROWS 1000;
CREATE OR REPLACE FUNCTION trigger_delete_user()
  RETURNS trigger AS
$BODY$
DECLARE
    ForKEY RECORD;
BEGIN
	FOR ForKEY IN SELECT tc.table_name, kcu.column_name, ccu.table_name AS foreign_table_name,ccu.column_name AS foreign_column_name 
		FROM information_schema.table_constraints  tc 
		JOIN information_schema.key_column_usage kcu ON tc.constraint_name = kcu.constraint_name 
		JOIN information_schema.constraint_column_usage ccu ON ccu.constraint_name = tc.constraint_name WHERE constraint_type = 'FOREIGN KEY' AND ccu.table_name='esia_users' LOOP

	EXECUTE 'DELETE FROM '|| ForKEY.table_name || ' WHERE '||ForKEY.column_name||' = '||OLD.user_id;
	END LOOP;
	RETURN OLD;
END;
$BODY$
  LANGUAGE plpgsql VOLATILE
  COST 100;
CREATE TRIGGER "deleteUser"
  BEFORE DELETE
  ON esia_users
  FOR EACH ROW
  EXECUTE PROCEDURE trigger_delete_user();

--DASHBOARD

CREATE TABLE dashboard
(
  dashboard_id serial NOT NULL,
  dashboard_name character varying,
  dashboard_controller character varying,
  dashboard_description character varying,
  CONSTRAINT "dashboards_primaryKey" PRIMARY KEY (dashboard_id)
);
ALTER TABLE dashboard OWNER TO esia;

-- Table: dashboard_tile

-- DROP TABLE dashboard_tile;

CREATE TABLE dashboard_tile
(
  tile_id serial NOT NULL,
  tile_position integer,
  tile_height integer,
  tile_width double precision,
  tile_dashboard_id integer,
  CONSTRAINT "tile_PrimaryKey" PRIMARY KEY (tile_id),
  CONSTRAINT "tile_dashboard_id_ForeignKey" FOREIGN KEY (tile_dashboard_id)
      REFERENCES dashboard (dashboard_id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION
);
ALTER TABLE dashboard_tile OWNER TO esia;

-- Table: dashboard_view

-- DROP TABLE dashboard_view;

CREATE TABLE dashboard_view
(
  view_id serial NOT NULL,
  view_name character varying(30),
  view_file_path character varying,
  view_during integer,
  view_default_height integer,
  view_default_width integer,
  view_default_option json,
  CONSTRAINT "dashboard_view_primaryKey" PRIMARY KEY (view_id)
);

ALTER TABLE dashboard_view OWNER TO esia;



-- Table: dashboard_user_access

-- DROP TABLE dashboard_user_access;

CREATE TABLE dashboard_user_access
(
  board_user_id integer NOT NULL,
  board_dashboard_id integer NOT NULL,
  board_user_share boolean DEFAULT false,
  CONSTRAINT "dashboard_user_access_primaryKey" PRIMARY KEY (board_user_id, board_dashboard_id),
  CONSTRAINT "dashboard_user_access_dashboard_id_foreignKey" FOREIGN KEY (board_dashboard_id)
      REFERENCES dashboard (dashboard_id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT "dashboard_user_id_foreignKey" FOREIGN KEY (board_user_id)
      REFERENCES esia_users (user_id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION
);
ALTER TABLE dashboard_user_access OWNER TO esia;

CREATE TABLE dashboard_widget
(
  widget_id serial NOT NULL,
  widget_name character varying,
  widget_view_during integer,
  widget_position integer,
  widget_option json,
  widget_tile_id integer,
  widget_view_id integer,
  widget_description character varying(150),
  CONSTRAINT "widget_primaryKey" PRIMARY KEY (widget_id),
  CONSTRAINT "dashboard_view_id_foreignKey" FOREIGN KEY (widget_view_id)
      REFERENCES dashboard_view (view_id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT "widget_tile_id_foreignKey" FOREIGN KEY (widget_tile_id)
      REFERENCES dashboard_tile (tile_id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION
);
CREATE TABLE report_send_users (
	send_canevas_id integer,
	send_user_id integer,
	CONSTRAINT report_send_users_ForKey_send_canevas_id FOREIGN KEY (send_canevas_id)
	REFERENCES report_canevas(canevas_id) MATCH SIMPLE ON UPDATE NO ACTION ON DELETE NO ACTION,
	CONSTRAINT report_send_users_ForKey_send_user_id FOREIGN KEY (send_user_id)
	REFERENCES esia_users(user_id) MATCH SIMPLE ON UPDATE NO ACTION ON DELETE NO ACTION
	);

CREATE TABLE esia_device_group
(
  device_group_id serial NOT NULL,
  device_group_name character varying(25),
  device_group_parent integer,
  device_group_order integer,
  CONSTRAINT "esia_device_group_PrimaryKey" PRIMARY KEY (device_group_id),
  CONSTRAINT "esia_device_group_ForeignKey_device_group_id" FOREIGN KEY (device_group_parent)
      REFERENCES esia_device_group (device_group_id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION
);
CREATE TABLE esia_device_group_in
(
   group_in_device_id integer, 
   group_in_device_group_id integer, 
   CONSTRAINT "device_group_in_PrimaryKey" PRIMARY KEY (group_in_device_id, group_in_device_group_id), 
   CONSTRAINT "device_group_in_ForeignKey_device_id" FOREIGN KEY (group_in_device_id) REFERENCES esia_device (device_id) ON UPDATE NO ACTION ON DELETE NO ACTION, 
   CONSTRAINT "device_group_in_ForeignKey_device_group_id" FOREIGN KEY (group_in_device_group_id) REFERENCES esia_device_group (device_group_id) ON UPDATE NO ACTION ON DELETE NO ACTION
);


CREATE TABLE esia_interface_connected_to
(
  conint_switch_interface_id integer NOT NULL,
  conint_interface_id2 integer NOT NULL,
  conint_protocol character varying(10) DEFAULT 'MACTABLE'::character varying,
  CONSTRAINT "conint_primaryKey" PRIMARY KEY (conint_switch_interface_id, conint_interface_id2),
  CONSTRAINT "conint_foreignKey_interface_id1" FOREIGN KEY (conint_switch_interface_id)
      REFERENCES esia_interface (interface_id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT "conint_foreignKey_interface_id2" FOREIGN KEY (conint_interface_id2)
      REFERENCES esia_interface (interface_id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION
);
ALTER TABLE report_send_users
  ADD CONSTRAINT "report_primaryKey" PRIMARY KEY(send_canevas_id, send_user_id);
